#ifndef SD5238_H
#define SD5238_H

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>
#include <dirent.h>
#include <math.h>
#include <float.h>
#include <sys/time.h>
#include <sys/types.h>

#include "gmt_functionV1_1_3.h"

/**************************************************************************************
 *						 
 *  	FILENAME:		SD5238.H		
 *
 *  	DRIVER:    															 
 *    	DESCRIPTION:	DJ042PA-01A
 *						DJ080PA-01A
 *						DJ080PA-01B
 *						DJ103FA-01A
 *
 *    	Modified by:	Tonyder.Lin/CMI		
 *    	HISTORY:    		
 *		First Issue		2011/01/05 - LOT2
 *						2011/03/07 - transfer to GMT
 *				
 *						2011/05/05 - Add the value of gamma at initial driver.
 *						2011/07/07 - Add the limit value for testing function.
 *									 Add the OP voltage by Vout_4
 * 						2011/08/16 - Starting to use Eclipse
 *		
***************************************************************************************/
//**************************** Defination *********************************************
#define DEFINE 1
#if DEFINE
//*************************************************************************************
// Power lines
//*************************************************************************************
#define VGL			VoutM1
#define Vgl			-7
#define VGH			Vout_6
#define Vgh			16
#define VDDP		Vout_5
#define Vddp		6.7
#define VDDN		VoutM0
#define Vddn		-6.3
#define VOP			Vout_4
#define Vop			18

//*************************************************************************************
// Panel control lines
//*************************************************************************************
#define VBL							VoutM3
#define Vbl							10
#define TB/*UD*/	  				IOcont_9		// Top to Button/Button to Top 0'/1'
#define RESET						IOcont_10		// Reset/Normal Operation 0'/1'
#define RL							IOcont_11		// Right to Left/Left to Right 0'/1'
#define EEPEN						IOcont_12		// disable/enable external EEPROM 0'/1'
#define DINT						IOcont_13		// 6bit/8bit mode	0'/1'
#define PW_EN						IOcont_14		// Power enable, HIGH to active
//#define PWM						IOcont_8		// PWM output, no use in this version
#define BIST						IOcont_15		// BIST mode disable/enable 0'/1'
//*************************************************************************************
// Data lines
//*************************************************************************************
#define D0	  						IOdata_0		 //B0	 A5 
#define D1	  						IOdata_1		 //B1	 B5
#define D2	  						IOdata_2		 //B2	 A6
#define D3	  						IOdata_3		 //B3	 B6
#define D4	  						IOdata_4  		 //B4	 A7
#define D5	  						IOdata_5		 //B5	 B7
#define D6	  						IOdata_6  		 //B6	 A8
#define D7	  						IOdata_7		 //B7	 B8
#define D8	  						IOdata_8  		 //G0	 A9
#define D9	  						IOdata_9		 //G1	 B9
#define D10	  						IOdata_10		 //G2	 A10
#define D11	  						IOdata_11  		 //G3	 B10
#define D12	  						IOdata_12		 //G4	 A11
#define D13	  						IOdata_13  		 //G5	 B11
#define D14	  						IOdata_14		 //G6	 A12
#define D15	  						IOdata_15		 //G7	 B12
#define D16	  						Odata_16  		 //R0	 A13
#define D17	  						Odata_17		 //R1	 B13
#define D18	  						Odata_18  		 //R2	 A14
#define D19	  						Odata_19		 //R3	 B14
#define D20	  						Odata_20  		 //R4	 A15
#define D21	  						Odata_21		 //R5	 B15
#define D22	  						Odata_22  		 //R6	 A16
#define D23	  						Odata_23		 //R7	 B16

#define DBlue						D0+D1+D2+D3+D4+D5+D6+D7
#define DGreen						D8+D9+D10+D11+D12+D13+D14+D15
#define DRed						D16+D17+D18+D19+D20+D21+D22+D23
#define ALLDATA						DBlue+DGreen+DRed

#define PCLK						Ocont_0
#define DE							Ocont_1
#define HS							Ocont_2
#define VS							Ocont_3
//*************************************************************************************
// SPI lines
//*************************************************************************************
#define SCL							Ocont_4
#define CSB							IOcont_8
#define SDAI						Ocont_5			// MOSI
#define SDAO						Icont_6			// MISO
#define POWER						Vout_3

#define VCC							0.52
//*************************************************************************************
// OTP lines
//*************************************************************************************
uint8_t flicker_input	=			Ain15;			// flicker sensor
#define VDD_OTP						VoutM2
#define VDD_otp						7.5
//*************************************************************************************
// NTC lines
//*************************************************************************************
#define NTC1						Ain13
#define NTC2						Ain14
//*************************************************************************************
// Sensor
//*************************************************************************************
#define VBL_SEN						Ain16
#define VCC_SEN						Ain17
#define VDDP_SEN					I_Vout5
#define VDDN_SEN					I_VoutM0
#define VGH_SEN						I_Vout6
#define VGL_SEN						I_VoutM1

#endif
#endif
