#ifndef SPI_H
#define SPI_H

#define S93C56B TRUE
#define SD5238 TRUE

extern uint16_t SPI_CS;
extern uint16_t SPI_MOSI;
extern uint16_t SPI_MISO;
extern uint16_t SPI_CLK;

unsigned char SPI_Write(unsigned int CMD,unsigned int Addr,unsigned int DataIn)
{
#ifdef S93C56B
	unsigned int i;	
	ResetDigitalControl(SPI_CLK);
	ResetDigitalControl(SPI_MOSI);			
	Wait(1);																			   		
	SetDigitalControl(SPI_CS);
	Wait(1);					
	SetDigitalControl(SPI_MOSI);				//start bit				
	SetDigitalControl(SPI_CLK);	
	for(i = 0; i < 2; i++)
	{	
		ResetDigitalControl(SPI_CLK);		
		if((CMD & 0x02) == 0x02)
			SetDigitalControl(SPI_MOSI);
		else
			ResetDigitalControl(SPI_MOSI);
		ResetDigitalControl(SPI_CLK);
		SetDigitalControl(SPI_CLK);				//command bit
		CMD = CMD << 1;		
	}
	
	for(i = 0; i < 8; i++)
	{	
		ResetDigitalControl(SPI_CLK);
		if((Addr & 0x80) == 0x80)
			SetDigitalControl(SPI_MOSI);
		else							 
			ResetDigitalControl(SPI_MOSI);
		SetDigitalControl(SPI_CLK);				 //address bit
		Addr = Addr << 1;		
	}
	for(i = 0; i < 16; i++)
	{		
		ResetDigitalControl(SPI_CLK);		
		if((DataIn & 0x8000) == 0x8000)
			SetDigitalControl(SPI_MOSI);
		else
			ResetDigitalControl(SPI_MOSI);		
		SetDigitalControl(SPI_CLK);				 //data bit

		DataIn = DataIn << 1;
	}

	ResetDigitalControl(SPI_CLK);
	Wait(10);
	ResetDigitalControl(SPI_CS);
#endif
//#ifdef //other device

//#endif
	return 0;

}
unsigned char SPI_Read(unsigned int CMD,unsigned int Addr,unsigned int *DataOut)
{
#ifdef S93C56B
	unsigned int i=0;	
	*DataOut = 0x00;
	ResetDigitalControl(SPI_CLK);
	ResetDigitalControl(SPI_MOSI);
	Wait(1);																			   		
	SetDigitalControl(SPI_CS);
	Wait(1);					
	SetDigitalControl(SPI_MOSI);				//start bit				
	SetDigitalControl(SPI_CLK);	
	for(i = 0; i < 2; i++)
	{	
		ResetDigitalControl(SPI_CLK);		
		if((CMD & 0x02) == 0x02)
			SetDigitalControl(SPI_MOSI);
		else
			ResetDigitalControl(SPI_MOSI);
		SetDigitalControl(SPI_CLK);
		CMD = CMD << 1;		
	}
	
	for(i = 0; i < 8; i++)
	{	
		ResetDigitalControl(SPI_CLK);
		if((Addr & 0x80) == 0x80)
			SetDigitalControl(SPI_MOSI);
		else							 
			ResetDigitalControl(SPI_MOSI);
		SetDigitalControl(SPI_CLK);
		Addr = Addr << 1;		
	}	
	ResetDigitalControl(SPI_CLK);				 //empty bit	
	for(i = 0; i < 16; i++)
	{		
		SetDigitalControl(SPI_CLK);
		*DataOut = *DataOut << 1;				
		*DataOut = *DataOut |(unsigned int)(((InputDigitalControl() & SPI_MISO)>> 6));
		ResetDigitalControl(SPI_CLK);			 //data bit
	}	
	Wait(1);		    
	ResetDigitalControl(SPI_CS);
#endif
//#ifdef //other device

//#endif
	
	return 0;
	
}

 
unsigned char SPI_RW_Burst(	unsigned int CMD,
							unsigned int Addr,
							unsigned int** DataIn,
							unsigned int* DataOut,
							unsigned int* Length)
{

	unsigned int i, j;
	unsigned int input;
	ResetDigitalControl(SPI_CLK);
	ResetDigitalControl(SPI_MOSI);			
	Wait(1);																			   		
	ResetDigitalControl(SPI_CS);
	Wait(1);					
	for(i = 0; i < 3; i++)
	{	
		ResetDigitalControl(SPI_CLK);		
		if((CMD & 0x04) == 0x04)
			SetDigitalControl(SPI_MOSI);
		else
			ResetDigitalControl(SPI_MOSI);
		ResetDigitalControl(SPI_CLK);
		SetDigitalControl(SPI_CLK);				//command bit
		CMD = CMD << 1;		
	}
	
	for(i = 0; i < 5; i++)
	{	
		ResetDigitalControl(SPI_CLK);
		if((Addr & 0x10) == 0x10)
			SetDigitalControl(SPI_MOSI);
		else							 
			ResetDigitalControl(SPI_MOSI);
		SetDigitalControl(SPI_CLK);				 //address bit
		Addr = Addr << 1;		
	}
	
	for(j = 0; j < *Length; j++)
	{	
		input = *(*DataIn + j);
		*(DataOut+j) = 0;
		
		for(i = 0; i < 8; i++)
		{		
			ResetDigitalControl(SPI_CLK);
			//write bit			
			if(((input) & 0x80) == 0x80)
				SetDigitalControl(SPI_MOSI);
			else
				ResetDigitalControl(SPI_MOSI);
			input = input << 1;
			
			//read bit
			*(DataOut + j) = *(DataOut + j) << 1;				
			*(DataOut + j) = *(DataOut + j) |(unsigned int)(((InputDigitalControl() & SPI_MISO)>> 6));			
			SetDigitalControl(SPI_CLK);	//data bit
		} 
	}
	
	ResetDigitalControl(SPI_CLK);
	Wait(10);
	SetDigitalControl(SPI_CS);
 	
	return 0;
}


unsigned char test_value_function(	unsigned int CMD,
									unsigned int Addr,
									unsigned int**	DataIn,
									unsigned int*	DataOut)
{
	
	unsigned int temp[2];		
	Clear_Screen();
	CMD = 0;
	Addr = 0;
	Display_Integer("Data In is %d", **DataIn);
	Display_Integer("Data Out is %d", *DataOut);
	while(!Halt_Pressed());		
		Wait_Halt(100);
		*DataOut = 0x66;
		temp[0]= 0x99;
		*DataIn = temp;
	Clear_Screen();
	Display_Integer("Data In is %d", **DataIn);
	Display_Integer("Data Out is %d", *DataOut);
	while(!Halt_Pressed());		
		Wait_Halt(100);
	return 0;
}

#endif
